QM9 consists of computed geometric, energetic, electronic, and thermodynamic
properties for 134k stable small organic molecules made up of C, H, O, N, and F.
As usual, we remove the uncharacterized molecules and provide the remaining
130,831.
